@@ -1,31 +1,32 @@
 from __future__ import annotations
 
+from typing import Hashable
 from typing import Iterable
+from typing import Literal
 
 import pandas as pd
 
-from dtoolkit._typing import IntOrStr
 from dtoolkit._typing import SeriesOrFrame
-from dtoolkit.accessor.dataframe import boolean  # noqa
+from dtoolkit.accessor.dataframe import boolean  # noqa: F401
 from dtoolkit.accessor.register import register_dataframe_method
 
 
 @register_dataframe_method
 def filter_in(
     df: pd.DataFrame,
-    condition: Iterable | SeriesOrFrame | dict[IntOrStr, list[IntOrStr]],
-    how: str = "all",
+    condition: Iterable | SeriesOrFrame | dict[Hashable, list[Hashable]],
+    /,
+    how: Literal["any", "all"] = "all",
     complement: bool = False,
 ) -> pd.DataFrame:
     """
     Filter :obj:`~pandas.DataFrame` contents.
 
-    Similar to :meth:`~pandas.DataFrame.isin`, but the return is value not
-    bool.
+    Similar to :meth:`~pandas.DataFrame.isin`, but the return is not bool.
 
     Parameters
     ----------
-    condition : iterable, Series, DataFrame or dict
+    condition : Iterable, Series, DataFrame or dict
         The filtered result is based on this specific condition.
 
         * If ``condition`` is a :obj:`dict`, the keys must be the column
@@ -59,6 +60,9 @@ def filter_in(
         Subset the dataframe rows or columns according to the specified index
         labels.
 
+    dtoolkit.accessor.series.filter_in
+        Filter Series contents.
+
     Examples
     --------
     >>> import dtoolkit.accessor
@@ -119,10 +123,7 @@ def filter_in(
     """
 
     return df[
-        df.pipe(
-            select_column,
-            condition=condition,
-        )
+        select_column(df, condition=condition)
         .isin(condition)
         .boolean(
             how=how,
@@ -134,7 +135,8 @@ def filter_in(
 
 def select_column(
     df: pd.DataFrame,
-    condition: Iterable | SeriesOrFrame | dict[IntOrStr, list[IntOrStr]],
+    /,
+    condition: Iterable | SeriesOrFrame | dict[Hashable, list[Hashable]],
 ) -> pd.DataFrame:
     """Select DataFram columns via condition type"""
 
