@@ -1,8 +1,9 @@
 from __future__ import annotations
 
+from typing import Hashable
+
 import pandas as pd
 
-from dtoolkit._typing import IntOrStr
 from dtoolkit._typing import Number
 from dtoolkit._typing import OneDimArray
 from dtoolkit.accessor.register import register_series_method
@@ -12,7 +13,8 @@ from dtoolkit.accessor.register import register_series_method
 def error_report(
     s: pd.Series,
     predicted: OneDimArray | list[Number],
-    columns: list[IntOrStr] = None,
+    /,
+    columns: list[Hashable] = None,
 ) -> pd.DataFrame:
     """
     Calculate `absolute error` and `relative error` of two columns.
@@ -22,7 +24,7 @@ def error_report(
     predicted : list of int or float, ndarrray, Series
         A array is compared to ``s``.
 
-    columns : list of str or int, optional
+    columns : list of Hashable, optional
         The columns of returning DataFrame, each represents `true value`,
         `predicted value`, `absolute error`, and `relative error`.
 
@@ -32,6 +34,13 @@ def error_report(
         Return four columns DataFrame and each represents `true value`,
         `predicted value`, `absolute error`, and `relative error`.
 
+    Raises
+    ------
+    IndexError
+        - If ``len(s)`` != ``len(predicted)``.
+        - If ``predicted`` is Series and its index not equal to ``s``'s index.
+        - ``columns`` isn't empty and its length is not equal to 4.
+
     Examples
     --------
     >>> import dtoolkit.accessor
@@ -64,7 +73,7 @@ def error_report(
     2  3  1  2  0.666667
     """
 
-    if len(s) != len(predicted):
+    if s.size != len(predicted):
         raise IndexError(
             "Length of 'predicted' doesn't match length of 'reference'.",
         )
